@@ -36,10 +36,10 @@ function _aws_cdk_aws_fsx_LustreFileSystemProps(p) {
         _aws_cdk_aws_fsx_LustreConfiguration(p.lustreConfiguration);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_fsx_FileSystemProps(p) {
-}
 function _aws_cdk_aws_fsx_LustreFileSystem(p) {
 }
+function _aws_cdk_aws_fsx_FileSystemProps(p) {
+}
 function _aws_cdk_aws_fsx_CfnFileSystemProps(p) {
     if (p == null)
         return;
@@ -79,5 +79,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_fsx_LustreDeploymentType, _aws_cdk_aws_fsx_Weekday, _aws_cdk_aws_fsx_IFileSystem, _aws_cdk_aws_fsx_LustreMaintenanceTimeProps, _aws_cdk_aws_fsx_LustreMaintenanceTime, _aws_cdk_aws_fsx_FileSystemAttributes, _aws_cdk_aws_fsx_LustreConfiguration, _aws_cdk_aws_fsx_FileSystemBase, _aws_cdk_aws_fsx_LustreFileSystemProps, _aws_cdk_aws_fsx_FileSystemProps, _aws_cdk_aws_fsx_LustreFileSystem, _aws_cdk_aws_fsx_CfnFileSystemProps, _aws_cdk_aws_fsx_CfnFileSystem, _aws_cdk_aws_fsx_CfnFileSystem_AuditLogConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_DiskIopsConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_SelfManagedActiveDirectoryConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_LustreConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_OntapConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_WindowsConfigurationProperty };
+module.exports = { print, _aws_cdk_aws_fsx_LustreDeploymentType, _aws_cdk_aws_fsx_Weekday, _aws_cdk_aws_fsx_IFileSystem, _aws_cdk_aws_fsx_LustreMaintenanceTimeProps, _aws_cdk_aws_fsx_LustreMaintenanceTime, _aws_cdk_aws_fsx_FileSystemAttributes, _aws_cdk_aws_fsx_LustreConfiguration, _aws_cdk_aws_fsx_FileSystemBase, _aws_cdk_aws_fsx_LustreFileSystemProps, _aws_cdk_aws_fsx_LustreFileSystem, _aws_cdk_aws_fsx_FileSystemProps, _aws_cdk_aws_fsx_CfnFileSystemProps, _aws_cdk_aws_fsx_CfnFileSystem, _aws_cdk_aws_fsx_CfnFileSystem_AuditLogConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_DiskIopsConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_SelfManagedActiveDirectoryConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_LustreConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_OntapConfigurationProperty, _aws_cdk_aws_fsx_CfnFileSystem_WindowsConfigurationProperty };
 module.exports.DeprecationError = DeprecationError;
